(user.getting_started)=
# Getting Started
This section provides a comprehensive guide to getting started with BEC Widgets. Whether you are new to BEC Widgets or looking to refresh your knowledge, this guide will help you set up and navigate the framework with ease.

```{toctree}
---
maxdepth: 2
hidden: true
---

installation/
quick_start/
auto_updates/
video_tutorials/
```